# GeoSpace

# Installation

For best results, or to run the rpy2 based comparisons, installing in 
an isolated environment is recommended. A conda environment including
GeoSpace and all requirements can be 
created with the included environment.yml file:

`conda env create environment.yml`

`conda activate geospace`

The GeoSpace package can be installed separately via pip:

`pip install geospace-st`

